@@ -794,7 +794,6 @@ void CProjectInfoPage::EllipseStringIfNeeded(wxString& s, wxWindow *win) {
     wxSize sz = win->GetParent()->GetSize();
     win->GetPosition(&x, &y);
     int maxWidth = sz.GetWidth() - x - 10;
-    
     win->GetTextExtent(s, &w, &h);
     
     // Adapted from ellipis code in wxRendererGeneric::DrawHeaderButtonContents()
@@ -814,3 +813,9 @@ void CProjectInfoPage::EllipseStringIfNeeded(wxString& s, wxWindow *win) {
         }
     }
 }
+
+void CProjectInfoPage::RefreshPage() {
+    // Trigger initial event to populate the list control
+    wxCommandEvent evtEvent(wxEVT_COMMAND_COMBOBOX_SELECTED, ID_CATEGORIES);
+    ProcessEvent(evtEvent);
+}
