@@ -201,7 +201,7 @@ function stage_files(&$jobs) {
 // submit a list of jobs with a single create_work command.
 //
 function submit_jobs(
-    $jobs, $template, $app, $batch_id, $priority, $app_version_num,
+    $jobs, $job_params, $app, $batch_id, $priority, $app_version_num,
     $input_template_filename,        // batch-level; can also specify per job
     $output_template_filename
 ) {
@@ -254,6 +254,21 @@ function submit_jobs(
     if ($app_version_num) {
         $cmd .= " --app_version_num $app_version_num";
     }
+    if ($job_params->rsc_disk_bound) {
+        $cmd .= " --rsc_disk_bound $job_params->rsc_disk_bound";
+    }
+    if ($job_params->rsc_fpops_est) {
+        $cmd .= " --rsc_fpops_est $job_params->rsc_fpops_est";
+    }
+    if ($job_params->rsc_fpops_bound) {
+        $cmd .= " --rsc_fpops_bound $job_params->rsc_fpops_bound";
+    }
+    if ($job_params->rsc_memory_bound) {
+        $cmd .= " --rsc_memory_bound $job_params->rsc_memory_bound";
+    }
+    if ($job_params->delay_bound) {
+        $cmd .= " --delay_bound $job_params->delay_bound";
+    }
     $cmd .= " --stdin >$errfile 2>&1";
     $h = popen($cmd, "w");
     if ($h === false) {
@@ -367,7 +382,7 @@ function xml_get_jobs($r) {
     return $jobs;
 }
 
-// $r is a simplexml object for the request message
+// $r is a simplexml object encoding the request message
 //
 function submit_batch($r) {
     xml_start_tag("submit_batch");
@@ -382,6 +397,10 @@ function submit_batch($r) {
     $njobs = count($jobs);
     $now = time();
     $app_version_num = (int)($r->batch->app_version_num);
+
+    // batch may or may not already exist.
+    // If it does, make sure it's owned by this user
+    //
     $batch_id = (int)($r->batch->batch_id);
     if ($batch_id) {
         $batch = BoincBatch::lookup_id($batch_id);
@@ -407,6 +426,8 @@ function submit_batch($r) {
             $total_flops += $job->rsc_fpops_est;
         } else if ($job->input_template && $job->input_template->workunit->rsc_fpops_est) {
             $total_flops += (double) $job->input_template->workunit->rsc_fpops_est;
+        } else if ($r->batch->job_params->rsc_fpops_est) {
+            $total_flops += (double) $r->batch->job_params->rsc_fpops_est;
         } else {
             $x = (double) $template->workunit->rsc_fpops_est;
             if ($x) {
@@ -439,20 +460,20 @@ function submit_batch($r) {
         $batch = BoincBatch::lookup_id($batch_id);
     }
     
-    if ($r->batch->input_template_filename) {
-        $input_template_filename = $r->batch->input_template_filename;
-    } else {
-        $input_template_filename = null;
-    }
+    $job_params = new StdClass;
+    $job_params->rsc_disk_bound = (double) $r->batch->job_params->rsc_disk_bound;
+    $job_params->rsc_fpops_est = (double) $r->batch->job_params->rsc_fpops_est;
+    $job_params->rsc_fpops_bound = (double) $r->batch->job_params->rsc_fpops_bound;
+    $job_params->rsc_memory_bound = (double) $r->batch->job_params->rsc_memory_bound;
+    $job_params->delay_bound = (double) $r->batch->job_params->delay_bound;
+        // could add quorum-related stuff
 
-    if ($r->batch->output_template_filename) {
-        $output_template_filename = $r->batch->output_template_filename;
-    } else {
-        $output_template_filename = null;
-    }
+    $input_template_filename = (string) $r->batch->input_template_filename;
+    $output_template_filename = (string) $r->batch->output_template_filename;
+        // possibly empty
     
     submit_jobs(
-        $jobs, $template, $app, $batch_id, $let, $app_version_num,
+        $jobs, $job_params, $app, $batch_id, $let, $app_version_num,
         $input_template_filename,
         $output_template_filename
     );
@@ -543,22 +564,22 @@ function n_outfiles($wu) {
 // error:
 
 function show_job_details($wu) {
-    if ($wu->error_mask && WU_ERROR_COULDNT_SEND_RESULT) {
+    if ($wu->error_mask & WU_ERROR_COULDNT_SEND_RESULT) {
         echo "   <error>couldnt_send_result</error>\n";
     }
-    if ($wu->error_mask && WU_ERROR_TOO_MANY_ERROR_RESULTS) {
+    if ($wu->error_mask & WU_ERROR_TOO_MANY_ERROR_RESULTS) {
         echo "   <error>too_many_error_results</error>\n";
     }
-    if ($wu->error_mask && WU_ERROR_TOO_MANY_SUCCESS_RESULTS) {
+    if ($wu->error_mask & WU_ERROR_TOO_MANY_SUCCESS_RESULTS) {
         echo "   <error>too_many_success_results</error>\n";
     }
-    if ($wu->error_mask && WU_ERROR_TOO_MANY_TOTAL_RESULTS) {
+    if ($wu->error_mask & WU_ERROR_TOO_MANY_TOTAL_RESULTS) {
         echo "   <error>too_many_total_results</error>\n";
     }
-    if ($wu->error_mask && WU_ERROR_CANCELLED) {
+    if ($wu->error_mask & WU_ERROR_CANCELLED) {
         echo "   <error>cancelled</error>\n";
     }
-    if ($wu->error_mask && WU_ERROR_NO_CANONICAL_RESULT) {
+    if ($wu->error_mask & WU_ERROR_NO_CANONICAL_RESULT) {
         echo "   <error>no_canonical_result</error>\n";
     }
     $results = BoincResult::enum("workunitid=$wu->id");
@@ -569,7 +590,7 @@ function show_job_details($wu) {
             $in_progress++;
             break;
         }
-        if ($wu->error_mask && $r->outcome == RESULT_OUTCOME_CLIENT_ERROR) {
+        if ($wu->error_mask && ($r->outcome == RESULT_OUTCOME_CLIENT_ERROR)) {
             echo "            <exit_status>$r->exit_status</exit_status>\n";
         }
         if ($r->id == $wu->canonical_resultid) {
