@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2018 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -220,6 +220,7 @@ void CC_CONFIG::defaults() {
     lower_client_priority = false;
     dont_suspend_nci = false;
     dont_use_vbox = false;
+    dont_use_wsl = false;
     exclude_gpus.clear();
     exclusive_apps.clear();
     exclusive_gpu_apps.clear();
@@ -355,6 +356,7 @@ int CC_CONFIG::parse_options(XML_PARSER& xp) {
         if (xp.parse_bool("lower_client_priority", lower_client_priority)) continue;
         if (xp.parse_bool("dont_suspend_nci", dont_suspend_nci)) continue;
         if (xp.parse_bool("dont_use_vbox", dont_use_vbox)) continue;
+        if (xp.parse_bool("dont_use_wsl", dont_use_wsl)) continue;
         if (xp.match_tag("exclude_gpu")) {
             EXCLUDE_GPU eg;
             retval = eg.parse(xp);
@@ -561,13 +563,15 @@ int CC_CONFIG::write(MIOFILE& out, LOG_FLAGS& log_flags) {
         "        <dont_contact_ref_site>%d</dont_contact_ref_site>\n"
         "        <lower_client_priority>%d</lower_client_priority>\n"
         "        <dont_suspend_nci>%d</dont_suspend_nci>\n"
-        "        <dont_use_vbox>%d</dont_use_vbox>\n",
+        "        <dont_use_vbox>%d</dont_use_vbox>\n"
+        "        <dont_use_wsl>%d</dont_use_wsl>\n",
         disallow_attach,
         dont_check_file_sizes,
         dont_contact_ref_site,
         lower_client_priority,
         dont_suspend_nci,
-        dont_use_vbox
+        dont_use_vbox,
+        dont_use_wsl
     );
 
     for (i=0; i<exclude_gpus.size(); i++) {
